@@ -1,10 +1,10 @@
-GOOF----LE-4-2.0\1      ] 4 4  hW      ] g  guile	 	g  define-module*	 	 	g  ice-9	g  common-list	 		g  filenameS	
+GOOF----LE-4-2.0,1      ] 2 4    h5      ] g  guile	 	g  define-module*	 	 	g  ice-9	g  common-list	 		g  filenameS	
 f  ice-9/common-list.scm	g  exportsS	g  adjoin	
 g  union	g  intersection	g  set-difference	g  reduce-init	g  reduce	g  some	g  every	g  notany	g  notevery	g  count-if	g  find-if	g  	member-if	g  	remove-if	g  
 remove-if-not	g  
 delete-if!	g  delete-if-not!	g  butlast	g  and?	g  or?	 g  has-duplicates?	!g  pick	"g  
 pick-mappings	#g  uniq	$
- !"# 	%g  set-current-module	&% 	'% 	(g  memq	)g  reverse!	*g  memv	+g  map	,g  car	-g  cdr	.g  	positive?	/g  length	0g  	negative?	1g  error	2f  negative argument to butlast	3g  memberC 5    h,  *  ]4	
+ !"# 	%g  set-current-module	&% 	'% 	(g  memq	)g  reverse!	*g  memv	+g  map	,g  car	-g  cdr	.g  length	/g  error	0f  negative argument to butlast	1g  memberC 5      hp,  *  ]4	
 $5 4' >  "  G   (  h      ]4 5$  C C       g  e
 		 g  l		  g  filenamef  ice-9/common-list.scm
 	M
@@ -116,14 +116,16 @@ delete-if-not C      h      ]
 delete-if-not			  g  filenamef  ice-9/common-list.scm
  
 	 	 			  g  nameg  delete-if-not!g  
-documentationf  'Destructive version of `remove-if-not'. CR.        h0      ] (   C45$   4L  	5CC             g  lst
-		* g  n		*  g  filenamef  ice-9/common-list.scm
- 		 		 		 		 		 	(	 	,	$ 	6	& 	(	' 		) 	 		*	  g  nameg  bl C/012  hH   <  ]HO Q 4 5K 45$  
-45"  J6   4      g  lst
-		E g  n		E g  l			E g  bl		
-	E g  l			%  g  filenamef  ice-9/common-list.scm
+documentationf  'Destructive version of `remove-if-not'. CR    h(      ] (   C
+$   4L  5CC          g  lst
+		% g  n		%  g  filenamef  ice-9/common-list.scm
+ 		 		 		 		 		 	(	 	,	 	6	! 	(	" 		$ 	 		%	  g  nameg  bl C./0    hH   <  ]HO Q 4 5K 
+$  
+45"  J6      4      g  lst
+		B g  n		B g  l			B g  bl		
+	B g  l			%  g  filenamef  ice-9/common-list.scm
  
-	 		 		 		* 		4 		5 		9 		= 		E 	 		E	  g  nameg  butlastg  
+	 		 		 		, 		1 		2 		6 		: 		B 	 		B	  g  nameg  butlastg  
 documentationf  *Return all but the last N elements of LST. CR   h(      -  1  3  (  C $   @C              g  args
 			!  g  filenamef  ice-9/common-list.scm
  
@@ -138,7 +140,7 @@ documentationf  #Return #t iff all of ARGS are true. CR   h(      -  1 
 
 
   g  nameg  or?g  
-documentationf  "Return #t iff any of ARGS is true. CR3    h(     ] (  C4  5$  C 6             g  lst
+documentationf  "Return #t iff any of ARGS is true. CR1    h(     ] (  C4  5$  C 6             g  lst
 		"  g  filenamef  ice-9/common-list.scm
  
 	 		 			 		 		 			 		  		" 	 
@@ -179,13 +181,13 @@ K	o
  
  
   
-# 
+#w 
 $ 
 % 
 & 
 ( 
 * 
-,w
+,g
 
- 	,y
+ 	,i
    C6 
\ No newline at end of file
